{% block content %}
<h1>Page Not Found</h1>
<p>Sorry, we couldn't find that page. Error code 404.</p>
<p>
  You can try using the search box above or check our menu on the left hand side
  of this page.
</p>
<p>
  If neither of those options work, please create a GitHub issue ticket in
  <a href="{{issue_page}}">{{project_name}}.</a>
</p>
<p>Or try sending a mail to <a href="mailto:{{mail_id}}">{{team_name}}</a></p>
.{% endblock %}
