@import "https://cdn.jsdelivr.net/npm/docs-searchbar.js@latest/dist/cdn/docs-searchbar.min.css";
@import "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css";

div[data-ds-theme] .searchbox {
  overflow-y: scroll;
  margin: auto;
}

.docs-searchbar-suggestion--category-header {
  background-color: var(--pst-color-border);
  border-radius: 7px;
  text-align: left;
}

/* Styles for screens with a width of 576px or less */
@media screen and (max-width: 576px) {
  div[data-ds-theme] .searchbox {
    width: 100%;
    max-width: 100%;
  }
  .bd-search input {
    width: 100% !important;
  }

  .index-select {
    width: 30%;
  }
}

/* Styles for screens with a width of 1200px or less */
@media screen and (min-width: 1200px) {
  div[data-ds-theme] .searchbox {
    width: 100%;
    max-width: 100%;
  }

  .bd-search input {
    width: 600px !important;
  }
  .index-select {
    width: 250px;
  }
}
.dsb-suggestions {
  width: 100%;
  max-width: 140%;
}

div[data-ds-theme] .meilisearch-autocomplete .dsb-dropdown-menu {
  max-width: 200%;
  min-width: 100%;
  width: 140%;
}
div[data-ds-theme] .meilisearch-autocomplete .docs-searchbar-suggestion {
  width: 100%;
}

div[data-ds-theme] .searchbox input {
  height: 32px;
  border-radius: 8px;
  font-size: 18px;
  font-family: "Open Sans", sans-serif;
  box-shadow: 0px 0px 8px darkgrey;
}

.docs-searchbar-footer {
  display: none;
}

.docs-searchbar-footer {
  display: none;
}

[class*="docs-searchbar-suggestion"] {
  text-decoration: none;
}

.docs-searchbar-suggestion--highlight {
  box-shadow: none !important;
}

.container {
  display: flex;
  justify-content: center;
  align-items: center;
}

div[data-ds-theme] .meilisearch-autocomplete {
  text-align: center;
  color: var(--pst-color-text-base);
}

#search-bar-input {
  background-color: var(--pst-color-background);
  border: 1px solid var(--pst-color-border);
  border-radius: 0.25rem;
  color: var(--pst-color-text-base);
  font-size: var(--pst-font-size-icon);
  position: relative;
  padding-left: 3rem;
}

.meilisearch-autocomplete::before {
  content: "\f002";
  font-family: "Font Awesome 6 Free";
  position: absolute;
  left: 8px;
  top: 50%;
  transform: translateY(-50%);
  font-size: 1rem;
  color: var(--pst-color-border);
}

.index-select {
  color: var(--pst-color-text-base);
  background: var(--pst-color-background);
  height: 47px;
  border: 1px solid var(--pst-color-border);
  border-radius: 0.25rem;
  font-size: 20px;
  font-family: "Open Sans", sans-serif;
  box-shadow: 0px 0px 20px var(--pst-color-border);
  padding: 0 10px 0px 10px;
  margin-left: 5px;
}

div[data-ds-theme]
  .meilisearch-autocomplete
  .dsb-dropdown-menu
  [class^="dsb-dataset-"] {
  position: relative;
  border: 1px solid #d9d9d9;
  background: var(--pst-color-background);
  border-radius: 4px;
  padding: 0 8px 8px;
}
div[data-ds-theme] .meilisearch-autocomplete .dsb-dropdown-menu {
  max-height: 600px !important;
  overflow-y: auto !important;
  border: 1px solid #ccc;
}

div[data-ds-theme] .meilisearch-autocomplete .docs-searchbar-suggestion {
  background: var(--pst-color-background);
}

div[data-ds-theme]
  .meilisearch-autocomplete
  .docs-searchbar-suggestion--highlight {
  color: var(--pst-color-info) !important;
  font-weight: 900;
  background: transparent;
  padding: 0 0.05em;
}

div[data-ds-theme]
  .meilisearch-autocomplete
  .docs-searchbar-suggestion--subcategory-column {
  width: None;
  text-align: left;
}

div[data-ds-theme]
  .meilisearch-autocomplete
  .docs-searchbar-suggestion--content {
  display: block;
}

div[data-ds-theme] .meilisearch-autocomplete .docs-searchbar-suggestion--title {
  margin-bottom: 4px;
  color: var(--pst-color-text-base);
  font-size: 0.9em;
  font-weight: 700;
  width: 100%;
}

/* Styling the scrollbar */
div[data-ds-theme]
  .meilisearch-autocomplete
  .dsb-dropdown-menu::-webkit-scrollbar {
  width: 0.5rem;
  height: 0.5rem;
}

div[data-ds-theme]
  .meilisearch-autocomplete
  .dsb-dropdown-menu::-webkit-scrollbar-thumb {
  background: var(--pst-color-text-base);
  border-radius: inherit;
}

div[data-ds-theme]
  .meilisearch-autocomplete
  .dsb-dropdown-menu::-webkit-scrollbar-track {
  background: var(--pst-color-background);
}

.bd-search {
  margin-bottom: 200px;
}
