/* Provided by the Sphinx base theme template at build time,
styles exclusively for the ansys-sphinx-theme classes. */

@import "ansys-sphinx-theme.css";

/*
############
breadcrumbs
############
*/

#breadcrumbs-spacer {
  border-right: 10rem solid var(--pst-color-background);
}

div.related > ul {
  padding: 10px 0 20px 0;
}

*,
:after,
:before {
  box-sizing: border-box;
}

/*
###########################
vesrion warning announcement
############################
*/

#announcement_msg {
  display: flex;
  justify-content: center;
  position: relative;
  width: 100%;
  padding: 0.5rem 12.5%;
  text-align: center;
}

#announcement_msg :after {
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0;
  top: 0;
  background-color: rgb(223, 95, 114);
  opacity: 0.2;
  content: "";
  z-index: -1;
}

#announcement_msg :empty {
  display: none;
}

#announcement_msg p {
  font-weight: bold;
  margin: auto;
  color: black;
}

html[data-theme="dark"] #announcement_msg :after {
  background-color: lightpink;
  opacity: 0.5;
}

#announcement_msg a {
  color: #1e6ddc;
}
